@@ -10,8 +10,8 @@ use crate::{
 use num_bigint::BigUint;
 
 use super::{
-    apply_fn_cache, deep_map_op_pre_new_children, deep_map_unwrap, visit_circuit, ArrayConstant,
-    Circuit, CircuitNode, CircuitRc, HashBytes, Index,
+    apply_fn_cache, deep_map_op_pre_new_children, deep_map_unwrap, visit_circuit_unwrap,
+    ArrayConstant, Circuit, CircuitNode, CircuitRc, HashBytes, Index,
 };
 use crate::tensor_util::TorchDeviceDtype;
 use std::hash::Hash;
@@ -71,13 +71,15 @@ pub fn cast_circuit(circ: CircuitRc, device_dtype: &TorchDeviceDtype) -> Circuit
 #[pyfunction]
 pub fn count_nodes(circuit: CircuitRc) -> usize {
     let mut result: usize = 0;
-    visit_circuit(circuit, &mut |_x: CircuitRc| result += 1);
+    visit_circuit_unwrap(circuit, &mut |_x: CircuitRc| {
+        result += 1;
+    });
     result
 }
 
 pub fn hash_to_node(circuit: CircuitRc) -> HashMap<HashBytes, CircuitRc> {
     let mut result: HashMap<HashBytes, CircuitRc> = HashMap::new();
-    visit_circuit(circuit, &mut |x: CircuitRc| {
+    visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
         result.insert(x.info().hash, x.clone());
     });
     result
@@ -85,7 +87,7 @@ pub fn hash_to_node(circuit: CircuitRc) -> HashMap<HashBytes, CircuitRc> {
 
 pub fn subcircuits(circuit: CircuitRc) -> HashSet<CircuitRc> {
     let mut result: HashSet<CircuitRc> = HashSet::new();
-    visit_circuit(circuit, &mut |x: CircuitRc| {
+    visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
         result.insert(x);
     });
     result
@@ -94,7 +96,9 @@ pub fn subcircuits(circuit: CircuitRc) -> HashSet<CircuitRc> {
 #[pyfunction]
 pub fn total_flops(circuit: CircuitRc) -> BigUint {
     let mut result: BigUint = BigUint::from(0usize);
-    visit_circuit(circuit, &mut |x: CircuitRc| result += x.self_flops());
+    visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
+        result += x.self_flops();
+    });
     result
 }
 
@@ -110,7 +114,7 @@ pub fn total_flops_cached(circuit: CircuitRc, cache: &mut HashMap<HashBytes, Big
 #[pyfunction]
 pub fn total_arrayconstant_size(circuit: CircuitRc) -> BigUint {
     let mut result: BigUint = BigUint::from(0usize);
-    visit_circuit(circuit, &mut |x: CircuitRc| {
+    visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
         if let Circuit::ArrayConstant(x) = &**x {
             result += x.info().numel();
         }
@@ -121,7 +125,7 @@ pub fn total_arrayconstant_size(circuit: CircuitRc) -> BigUint {
 #[pyfunction]
 pub fn sum_of_node_sizes(circuit: CircuitRc) -> BigUint {
     let mut result: BigUint = BigUint::from(0usize);
-    visit_circuit(circuit, &mut |x: CircuitRc| {
+    visit_circuit_unwrap(circuit, &mut |x: CircuitRc| {
         if !matches!(&**x, Circuit::ArrayConstant(_)) {
             result += x.info().numel();
         }
@@ -144,7 +148,7 @@ pub fn sum_of_node_sizes_cached(
 #[pyfunction]
 pub fn get_leaves(circuit: CircuitRc) -> Vec<CircuitRc> {
     let mut result: Vec<CircuitRc> = vec![];
-    visit_circuit(circuit, &mut |c: CircuitRc| {
+    visit_circuit_unwrap(circuit, &mut |c: CircuitRc| {
         if c.children().count() == 0 {
             result.push(c);
         }
@@ -155,7 +159,7 @@ pub fn get_leaves(circuit: CircuitRc) -> Vec<CircuitRc> {
 #[pyfunction]
 pub fn get_all_einsum_specs(circuit: CircuitRc) -> Vec<EinsumSpec> {
     let mut result: Vec<EinsumSpec> = vec![];
-    visit_circuit(circuit, |c| {
+    visit_circuit_unwrap(circuit, |c| {
         if let Circuit::Einsum(node) = &**c {
             result.push(node.get_spec());
         }
@@ -167,7 +171,7 @@ pub fn get_all_einsum_specs(circuit: CircuitRc) -> Vec<EinsumSpec> {
 /// children first
 pub fn toposort_circuit(circuit: CircuitRc) -> Vec<CircuitRc> {
     let mut num_refs: HashMap<CircuitRc, usize> = HashMap::new();
-    visit_circuit(circuit.clone(), |c| {
+    visit_circuit_unwrap(circuit.clone(), |c| {
         for child in c.children() {
             *num_refs.entry(child).or_insert(0) += 1;
         }
@@ -318,7 +322,7 @@ pub fn replace_all_randn_seeded(circuit: CircuitRc) -> CircuitRc {
 
 pub fn has_leaf_symbols(circuit: CircuitRc, allowed: &HashSet<HashBytes>) -> bool {
     let mut result = false;
-    visit_circuit(circuit, |circuit| {
+    super::visit_circuit_unwrap(circuit, |circuit| {
         if circuit.as_symbol().is_some() && !allowed.contains(&circuit.info().hash) {
             println!(
                 "found symbol {:?} allowed {:?}",
