@@ -93,10 +93,7 @@ pub fn einsum_pull_concat(einsum: &Einsum) -> Option<CircuitRc> {
                                 })
                                 .collect(),
                         );
-                        (
-                            Index::nrc(node.clone(), index, None),
-                            ints.clone(),
-                        )
+                        (Index::nrc(node.clone(), index, None), ints.clone())
                     })
                     .collect();
 
@@ -310,13 +307,11 @@ pub fn index_concat_drop_unreached(index: &Index) -> Option<CircuitRc> {
     }
     let mut new_tensor_index = index.index.clone();
     new_tensor_index.0[concat.axis] = new_index;
-    Some(
-        Index::nrc(
-            Concat::nrc(new_operands, concat.axis, concat.name_cloned()),
-            new_tensor_index,
-            index.name_cloned(),
-        )
-    )
+    Some(Index::nrc(
+        Concat::nrc(new_operands, concat.axis, concat.name_cloned()),
+        new_tensor_index,
+        index.name_cloned(),
+    ))
 }
 
 #[pyfunction]
