@@ -257,7 +257,11 @@ pub fn einsum_push_down_trace(einsum: &Einsum) -> Option<Einsum> {
     if !did_anything {
         return None;
     }
-    Some(Einsum::new(new_args, einsum.out_axes.clone(), einsum.name_cloned()))
+    Some(Einsum::new(
+        new_args,
+        einsum.out_axes.clone(),
+        einsum.name_cloned(),
+    ))
 }
 
 #[pyfunction]
