@@ -1,5 +1,6 @@
 use std::os::unix::prelude::OsStrExt;
 
+use crate::lru_cache::TensorCacheRrfs;
 use crate::pyo3_prelude::*;
 use crate::{
     circuit::ArrayConstant,
@@ -48,9 +49,10 @@ pub fn tensor_from_hash_prefix(hash_base16: &str) -> Result<Tensor, PyErr> {
         ));
     }
     if dir.is_empty() {
-        return Err(PyErr::new::<pyo3::exceptions::PyTypeError, _>(
-            "prefix not found",
-        ));
+        return Err(PyErr::new::<pyo3::exceptions::PyTypeError, _>(format!(
+            "prefix not found {}",
+            hash_base16
+        )));
     }
     tensor_from_hash(
         dir[0]
@@ -74,7 +76,13 @@ pub fn arrayconstant_from_hash(
 pub fn arrayconstant_from_hash_prefix(
     name: Option<String>,
     hash_base16: &str,
+    tensor_cache: &mut Option<TensorCacheRrfs>,
 ) -> Result<ArrayConstant, PyErr> {
+    if let Some(tc) = tensor_cache {
+        return tc
+            .get_tensor(hash_base16.to_owned())
+            .map(|value| ArrayConstant::new(value, name));
+    }
     tensor_from_hash_prefix(hash_base16).map(|value| ArrayConstant::new(value, name))
 }
 
